==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/screenshot/translations/screenshot_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Paramètres généraux</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Sélectionner le format d&apos;image dans lequel les captures d&apos;écran seront stockées et envoyées.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Forcer l&apos;extension .jpg pour le format JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Force l&apos;utilisation de l&apos;extension courte .jpg pour les fichiers au format JPEG. Certaines messageries instantanées l&apos;exigent.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Qualité des captures d&apos;écran</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 pour l&apos;auto-détection, 0 pour une compression optimal, 100 pour une image de qualité maximum.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Chemin du répertoire de captures d&apos;écran</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Préfixe des nom de fichiers de captures d&apos;écran</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Activer le contrôle de la taille du répertoire</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Taille maximum du répertoire</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> ko</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Limite de la taille des images de captures d&apos;écran</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Suppléments</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Format du fichier de la capture</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Automatiquement coller l&apos;image dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Quand activé, le plugin va automatiquement coller la clause près à envoyer[IMAGE] dans la conversation.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Quand activé, le plugin va vérifier la taille du répertoire de capture d&apos;écran et vous notifier si la taille atteint la taille spécifié ici.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Définir l&apos;espace maximal en k octets que peut prendre le répertoire de captures avant de vous avertir.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>La taille de l&apos;image est plus grande que la taille d&apos;image maximale pour ce chat.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Impossible de créer le répertoire %1 pour y stocker les captures d&apos;écran !</translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation>Impossible d&apos;écrire le fichier %1.
Accès refusé ou autre problème !</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>La capture d&apos;écran %1 a une taille nulle !
Elle devrait être plus grosse.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>ScreenShot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>Simple Shot</source>
        <translation>Capture d&apos;écran globle</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>Avec la fenêtre de discussion masquée</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Capture d&apos;écran d&apos;une fenêtre</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Limite de la taille des captures d&apos;écran</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>Limite de taille des images dépassée : %1 Ko</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Faites glisser cette icône sur la fenêtre désirée</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Capture d&apos;écran d&apos;une fenêtre</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 Kio</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Rogner</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/screenshot/translations/screenshot_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Paramètres généraux</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Sélectionner le format d&apos;image dans lequel les captures d&apos;écran seront stockées et envoyées.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Forcer l&apos;extension .jpg pour le format JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Force l&apos;utilisation de l&apos;extension courte .jpg pour les fichiers au format JPEG. Certaines messageries instantanées l&apos;exigent.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Qualité des captures d&apos;écran</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 pour l&apos;auto-détection, 0 pour une compression optimal, 100 pour une image de qualité maximum.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Chemin du répertoire de captures d&apos;écran</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Préfixe des nom de fichiers de captures d&apos;écran</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Activer le contrôle de la taille du répertoire</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Taille maximum du répertoire</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> ko</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Limite de la taille des images de captures d&apos;écran</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Suppléments</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Format du fichier de la capture</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Automatiquement coller l&apos;image dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Quand activé, le plugin va automatiquement coller la clause près à envoyer[IMAGE] dans la conversation.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Quand activé, le plugin va vérifier la taille du répertoire de capture d&apos;écran et vous notifier si la taille atteint la taille spécifié ici.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Définir l&apos;espace maximal en k octets que peut prendre le répertoire de captures avant de vous avertir.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>La taille de l&apos;image est plus grande que la taille d&apos;image maximale pour ce chat.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Impossible de créer le répertoire %1 pour y stocker les captures d&apos;écran !</translation>
    </message>
    <message>
        <source>Can't write file %1.
Access denied or other problem!</source>
        <translation>Impossible d&apos;écrire le fichier %1.
Accès refusé ou autre problème !</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>La capture d&apos;écran %1 a une taille nulle !
Elle devrait être plus grosse.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>Simple Shot</source>
        <translation>Capture d&apos;écran globle</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>Avec la fenêtre de discussion masquée</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Capture d&apos;écran d&apos;une fenêtre</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotificationService</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Limite de la taille des captures d&apos;écran</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>Limite de taille des images dépassée : %1 Ko</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Faites glisser cette icône sur la fenêtre désirée</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Capture d&apos;écran d&apos;une fenêtre</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 Kio</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Rogner</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>
